/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.queue;

/**
 * Attribute controller for queue implementation with a push input. It defines
 * an overflow policy attribute with three default values (specific
 * implementations can define other).
 */
public interface PushQueueAttributeController extends QueueAttributeController
{

  /**
   * An overflow policy that block incomming messages until a message is
   * delivered on the output. <br>
   * Warning when using this overflow policy a
   * {@link org.objectweb.dream.InterruptedPushException}may be thrown.
   */
  String BLOCK_OVERFLOW_POLICY     = "block";

  /**
   * An overflow policy that drops the new message and does not modify the
   * queue.
   */
  String DROP_OVERFLOW_POLICY      = "drop";

  /**
   * An overflow policy that cause the <code>Push</code> server interface to
   * throw a {@link BufferOverflowException}
   */
  String EXCEPTION_OVERFLOW_POLICY = "exception";

  /**
   * Returns the overflow policy.
   * 
   * @return the overflow policy.
   */
  String getOverflowPolicy();

  /**
   * Sets the overflow policy.
   * 
   * @param policy the overflow policy.
   * @throws IllegalArgumentException if the given string is not reconized as a
   *           valid policy.
   */
  void setOverflowPolicy(String policy);

}